@@ -380,6 +380,22 @@ struct qc_sensor_data {
 	unsigned int compress : 1;	/* Set into compressed mode? */
 };
 /* }}} */
+/* {{{ [fold] qc_int_data: INT command for reading interrupts from camera */
+#define INT_PACKET_SIZE		1	/* Max size of one packet (shouldn't be hardcoded JFC was 960) */
+struct qc_int_data {
+	struct urb *urb;		/* reading urb */
+	unsigned char *buffer;		/* transfer buffer */
+	size_t rawbufsize;
+	int errorcount;
+	int polling;
+	int abort_polling;
+
+	//volatile int packets;		/* 0=no URBs scheduled, 1=URB scheduled */
+	wait_queue_head_t wq;		/* Woken up when all pending data is sent */
+	IDEBUG_VAR
+};
+/* }}} */
+#if 0
 /* {{{ [fold] qc_i2c_data: I2C command queue for writing commands to camera */
 #define I2C_MAXCOMMANDS 	16	/* Should be about 1-2 times the size of transfer buffer (=16) for maximum performance */
 #define I2C_FLAG_WORD 		BIT(0)	/* Set if a 16-bit value is sent, otherwise 8-bit value */
@@ -401,6 +417,7 @@ struct qc_i2c_data {
 	IDEBUG_VAR
 };
 /* }}} */
+#endif
 /* {{{ [fold] qc_isoc_data: Isochronous transfer queue control data for reading from camera */
 #define ISOC_URBS		2	/* Number of URBs to use */
 #define ISOC_PACKETS		10	/* How many isochronous data packets per URB */
@@ -522,12 +539,20 @@ struct quickcam {
 	struct list_head list;			/* All cameras are in a doubly linked list */
 	int users;				/* User count (simultaneous open count) */
 	struct usb_device *dev;			/* USB device, set to NULL when camera disconnected and interrupts disabled */
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
+  //struct usb_interface *interface;
+#endif
+  //struct usb_interface_descriptor *ifacedesc;
+  int bEndpointAddress;
+
 	unsigned char iface;			/* The interface number in the camera device we are bound to */
 	Bool connected;				/* Set to FALSE immediately when the camera is disconnected (even before interrupts are disabled) */
 	struct video_device vdev;		/* Used for registering the camera driver for Video4Linux */
 	struct qc_settings_data settings;	/* General user settings set with e.g. qcset */
 #if HAVE_PROCFS
 	struct proc_dir_entry *proc_entry;
+	struct proc_dir_entry *proc_entry_button;
 #endif
 	/* The following entries are initialized in qc_v4l_init() when the camera device is opened */
 	struct video_picture vpic;		/* Contains the last values set by user (which is reported to user) */
@@ -535,7 +560,8 @@ struct quickcam {
 	struct video_window vwin;		/* Contains the image size and position the user is expecting */
 
 	/* Private structures for each module, initialized in corresponding init-function */
-	struct qc_i2c_data i2c_data;		/* Filled when the camera is plugged in or driver loaded */
+	struct qc_int_data int_data;		/* Filled when the camera is plugged in or driver loaded */
+	//struct qc_i2c_data i2c_data;		/* Filled when the camera is plugged in or driver loaded */
 	struct qc_adapt_data adapt_data;	/* Filled when the camera is plugged in or driver loaded */
 	struct qc_sensor_data sensor_data;	/* Mostly filled when the device is opened */
 	struct qc_stream_data stream_data;	/* Filled when the device is opened */
@@ -545,6 +571,16 @@ struct quickcam {
 	struct qc_fmt_data fmt_data;		/* Mostly filled when the device is opened, except for userlut */
 
 	u8 dmabuf[35];				/* Temporary buffer which may be used for DMA transfer */
+
+	int button_status;
+	int button_count;
+	int button_pressed;
+	int button_released;
+	int button_pressed_cum;
+	int button_released_cum;
+	int button_pressed_not_handled;
+	int reg1442;
+	int reg144a;
 };
 /* }}} */
 /* {{{ [fold] SECTION: miscelleneous */
@@ -576,11 +612,12 @@ struct qc_sensor {
 /* }}} */
 /* {{{ [fold] SECTION: function prototypes */
 /* USB interface chip control */
-int qc_i2c_break(struct quickcam *qc);
 int qc_i2c_wait(struct quickcam *qc);
+#if 0
+int qc_i2c_break(struct quickcam *qc);
 int qc_i2c_set(struct quickcam *qc, unsigned char reg, unsigned char val);
 int qc_i2c_setw(struct quickcam *qc, unsigned char reg, unsigned short val);
-
+#endif
 int qc_stv_set(struct quickcam *qc, unsigned short reg, unsigned char val);
 int qc_stv_setw(struct quickcam *qc, unsigned short reg, unsigned short val);
 int qc_stv_get(struct quickcam *qc, unsigned short reg);
@@ -598,7 +635,7 @@ int qc_mjpeg_init(struct qc_mjpeg_data *md, int depth, Bool tobgr);
 void qc_mjpeg_exit(struct qc_mjpeg_data *md);
 
 void qc_hsv2rgb(s16 hue, u16 sat, u16 val, int *red, int *green, int *blue);
-int qc_get_i2c(struct quickcam *qc, const struct qc_sensor *sensor, int reg);
+//int qc_get_i2c(struct quickcam *qc, const struct qc_sensor *sensor, int reg);
 void qc_frame_flush(struct quickcam *qc);
 
 void qc_usleep(unsigned long usec);
