@@ -168,6 +168,8 @@ set_res(struct video_mmap *vm)
     case 2:
       vm->width  = 248;
       vm->height = 162;
+      vm->width  = 352;
+      vm->height = 288;
       break;
     case 3:
       vm->width  = 324;
@@ -195,10 +197,19 @@ set_res(struct video_mmap *vm)
     vidwin.width = vm->width;
     vidwin.height = vm->height;
 
+    if((vidwin.width > vidcap.maxwidth) ||
+       (vidwin.height > vidcap.maxheight)) {
+      vidwin.width = vidcap.maxwidth;
+      vidwin.height = vidcap.maxheight;
+    }
     r=ioctl(device_fd, VIDIOCSWIN, &vidwin);
     if (r!=0) { perror("ioctl VIDIOCSWIN"); exit(1); }
+
     r=ioctl(device_fd, VIDIOCGWIN, &vidwin);
     if (r!=0) { perror("ioctl VIDIOCGWIN"); exit(1); }
+    vm->width = vidwin.width;
+    vm->height = vidwin.height;
+
     vidchan.channel = 0;
     r=ioctl(device_fd, VIDIOCGCHAN, &vidchan);
     if (r!=0) { perror("ioctl VIDIOCGCHAN"); exit(1); }
